@@ -39,6 +39,7 @@ static gchar *gtr_lib_dir = NULL;
 static gchar *gtr_plugins_dir = NULL;
 static gchar *gtr_plugins_data_dir = NULL;
 static gchar *gtr_pixmaps_dir = NULL;
+static gchar *gtr_sourceview_dir = NULL;
 
 void
 gtr_dirs_init ()
@@ -91,6 +92,7 @@ gtr_dirs_init ()
   gtr_plugins_data_dir = g_build_filename (gtr_data_dir, "plugins", NULL);
 
   gtr_pixmaps_dir = g_build_filename (gtr_data_dir, "pixmaps", NULL);
+  gtr_sourceview_dir = g_build_filename (gtr_data_dir, "sourceview", NULL);
 }
 
 void
@@ -106,6 +108,7 @@ gtr_dirs_shutdown ()
   g_free (gtr_plugins_dir);
   g_free (gtr_plugins_data_dir);
   g_free (gtr_pixmaps_dir);
+  g_free (gtr_sourceview_dir);
 }
 
 const gchar *
@@ -168,6 +171,12 @@ gtr_dirs_get_gtr_pixmaps_dir (void)
   return gtr_pixmaps_dir;
 }
 
+const gchar *
+gtr_dirs_get_gtr_sourceview_dir (void)
+{
+  return gtr_sourceview_dir;
+}
+
 gchar *
 gtr_dirs_get_ui_file (const gchar * file)
 {
