@@ -46,6 +46,8 @@
 #include "translation-memory/gtr-translation-memory-dialog.h"
 #include "translation-memory/gda/gtr-gda.h"
 
+#include "codeview/gtr-codeview.h"
+
 #include <glib.h>
 #include <glib-object.h>
 #include <glib/gi18n.h>
@@ -67,6 +69,8 @@ typedef struct
   GSettings *tm_settings;
   GtrTranslationMemory *translation_memory;
 
+  GtrCodeView *codeview;
+
   GtkWidget *header_bar;
   GtkWidget *main_box;
 
@@ -782,6 +786,9 @@ gtr_window_init (GtrWindow *window)
                                                             "max-length-diff"));
   gtr_translation_memory_set_max_items (priv->translation_memory, 10);
 
+  // code view
+  priv->codeview = gtr_code_view_new (window);
+
   gtr_window_show_projects (window);
 }
 
@@ -813,6 +820,7 @@ gtr_window_dispose (GObject * object)
   g_clear_object (&priv->prof_manager);
   g_clear_object (&priv->translation_memory);
   g_clear_object (&priv->tm_settings);
+  g_clear_object (&priv->codeview);
 
   G_OBJECT_CLASS (gtr_window_parent_class)->dispose (object);
 }
@@ -1260,9 +1268,11 @@ gtr_window_tm_keybind (GtrWindow *window,
   match = (GtrTranslationMemoryMatch *) g_list_nth_data (tm_list, index);
   if (match)
     {
+      gtk_text_buffer_begin_user_action (buffer);
       gtr_msg_set_msgstr (msg, match->match);
       gtk_text_buffer_set_text (buffer, match->match, -1);
       gtr_po_set_state (po, GTR_PO_STATE_MODIFIED);
+      gtk_text_buffer_end_user_action (buffer);
     }
 
   g_list_free_full (tm_list, free_match);
